@@ -1,3 +1,4 @@
+from sp_api.api.product_fees.models.get_my_fees_estimate_response import GetMyFeesEstimateResponse
 from sp_api.base.helpers import sp_endpoint, fill_query_params
 from sp_api.base import Client, Marketplaces
 
@@ -9,18 +10,19 @@ class ProductFees(Client):
     @sp_endpoint('/products/fees/v0/listings/{}/feesEstimate', method='POST')
     def get_product_fees_estimate_for_sku(self, seller_sku, price: float, currency='USD', **kwargs):
         kwargs.update({
-                'FeesEstimateRequest': {
-                    'Identifier': price,
-                    'PriceToEstimateFees': {
-                        'ListingPrice': {
-                            'Amount': price,
-                            'CurrencyCode': currency
-                        }
-                    },
-                    'MarketplaceId': self.marketplace_id
-                }
-            })
-        return self._request(fill_query_params(kwargs.pop('path'), seller_sku), data=kwargs).json()
+            'FeesEstimateRequest': {
+                'Identifier': price,
+                'PriceToEstimateFees': {
+                    'ListingPrice': {
+                        'Amount': price,
+                        'CurrencyCode': currency
+                    }
+                },
+                'MarketplaceId': self.marketplace_id
+            }
+        })
+        return GetMyFeesEstimateResponse(
+            **self._request(fill_query_params(kwargs.pop('path'), seller_sku), data=kwargs).json())
 
     @sp_endpoint('/products/fees/v0/items/{}/feesEstimate', method='POST')
     def get_product_fees_estimate_for_asin(self, asin, price: float, currency='USD', **kwargs):
@@ -36,4 +38,5 @@ class ProductFees(Client):
                 'MarketplaceId': self.marketplace_id
             }
         })
-        return self._request(fill_query_params(kwargs.pop('path'), asin), data=kwargs).jsom()
+        return GetMyFeesEstimateResponse(
+            **self._request(fill_query_params(kwargs.pop('path'), asin), data=kwargs).jsom())
